Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(339)

Unified Diff: runtime/vm/service_event.h

Issue 2411153002: Make reloadSources service RPC public (Closed)
Patch Set: turnidge review Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/service.cc ('k') | runtime/vm/service_event.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/service_event.h
diff --git a/runtime/vm/service_event.h b/runtime/vm/service_event.h
index cd48844ca3657c8c05fcde3d100c6e0d23fecc64..369f522f5bf44856f19067f3730e3287dcfdd980 100644
--- a/runtime/vm/service_event.h
+++ b/runtime/vm/service_event.h
@@ -37,7 +37,8 @@ class ServiceEvent {
kPauseBreakpoint,
kPauseInterrupted,
kPauseException,
- kNone, // isolate has not been made runnable yet.
+ kPausePostRequest, // isolate is paused after a service request.
+ kNone, // isolate has not been made runnable yet.
kResume,
kBreakpointAdded,
kBreakpointResolved,
@@ -92,6 +93,7 @@ class ServiceEvent {
case kPauseBreakpoint:
case kPauseInterrupted:
case kPauseException:
+ case kPausePostRequest:
return true;
default:
return false;
@@ -131,6 +133,7 @@ class ServiceEvent {
ASSERT(kind() == kPauseBreakpoint ||
kind() == kPauseInterrupted ||
kind() == kPauseException ||
+ kind() == kPausePostRequest ||
kind() == kResume);
top_frame_ = frame;
}
« no previous file with comments | « runtime/vm/service.cc ('k') | runtime/vm/service_event.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698